@@ -31,44 +31,49 @@ token.vertex <- function(jsonkey = NULL, model_id = NULL, expTime = 3600, region
     cli_alert_danger("JSON key file path must be provided.")
     return(NULL)
   }
-  
+
   if (!file.exists(jsonkey)) {
     cli_alert_danger(paste0("JSON key file not found: ", jsonkey))
     return(NULL)
   }
-  
+
   if (is.null(model_id)) {
     cli_alert_danger("Model ID must be provided.")
     return(NULL)
   }
-  
+
   # 2. Add status message
   sb <- cli_status("Authenticating with Vertex AI...")
-  
+
   # 3. Strengthen error handling
-  account <- tryCatch({
-    fromJSON(jsonkey)
-  }, error = function(e) {
-    cli_status_clear(id = sb)
-    cli_alert_danger(paste0("Error reading JSON key file: ", e$message))
-    return(NULL)
-  })
-  
+  account <- tryCatch(
+    {
+      fromJSON(jsonkey)
+    },
+    error = function(e) {
+      cli_status_clear(id = sb)
+      cli_alert_danger(paste0("Error reading JSON key file: ", e$message))
+      return(NULL)
+    }
+  )
+
   if (is.null(account)) {
     return(NULL)
   }
-  
+
   # Check required fields
   required_fields <- c("client_email", "private_key", "project_id")
   missing_fields <- required_fields[!required_fields %in% names(account)]
-  
+
   if (length(missing_fields) > 0) {
     cli_status_clear(id = sb)
-    cli_alert_danger(paste0("JSON key file missing required fields: ", 
-                            paste(missing_fields, collapse = ", ")))
+    cli_alert_danger(paste0(
+      "JSON key file missing required fields: ",
+      paste(missing_fields, collapse = ", ")
+    ))
     return(NULL)
   }
-  
+
   project_id <- account$project_id
 
   model_id <- paste0("gemini-", model_id, ":generateContent")
@@ -95,56 +100,65 @@ token.vertex <- function(jsonkey = NULL, model_id = NULL, expTime = 3600, region
   )
 
   # 4. Add error handling for JWT token creation
-  jwt_token <- tryCatch({
-    jwt_encode_sig(jwt_claims, account$private_key)
-  }, error = function(e) {
-    cli_status_clear(id = sb)
-    cli_alert_danger(paste0("Error creating JWT token: ", e$message))
-    return(NULL)
-  })
-  
+  jwt_token <- tryCatch(
+    {
+      jwt_encode_sig(jwt_claims, account$private_key)
+    },
+    error = function(e) {
+      cli_status_clear(id = sb)
+      cli_alert_danger(paste0("Error creating JWT token: ", e$message))
+      return(NULL)
+    }
+  )
+
   if (is.null(jwt_token)) {
     return(NULL)
   }
 
   # 5. Add error handling for API call
-  resp <- tryCatch({
-    request(token_url) |>
-      req_body_form(
-        grant_type = "urn:ietf:params:oauth:grant-type:jwt-bearer",
-        assertion = jwt_token
-      ) |>
-      req_perform()
-  }, error = function(e) {
-    cli_status_clear(id = sb)
-    cli_alert_danger(paste0("Error requesting access token: ", e$message))
-    return(NULL)
-  })
-  
+  resp <- tryCatch(
+    {
+      request(token_url) |>
+        req_body_form(
+          grant_type = "urn:ietf:params:oauth:grant-type:jwt-bearer",
+          assertion = jwt_token
+        ) |>
+        req_perform()
+    },
+    error = function(e) {
+      cli_status_clear(id = sb)
+      cli_alert_danger(paste0("Error requesting access token: ", e$message))
+      return(NULL)
+    }
+  )
+
   if (is.null(resp)) {
     return(NULL)
   }
-  
+
   # 6. Check response status code
   if (resp$status_code != 200) {
     cli_status_clear(id = sb)
     cli_alert_danger(paste0("Error response from token server: Status code ", resp$status_code))
     return(NULL)
   }
-  
+
   # 7. Add error handling for JSON response processing
-  token_data <- tryCatch({
-    resp_body_json(resp)
-  }, error = function(e) {
-    cli_status_clear(id = sb)
-    cli_alert_danger(paste0("Error processing JSON response: ", e$message))
-    return(NULL)
-  })
-  
+  token_data <- tryCatch(
+    {
+      resp_body_json(resp)
+    },
+    error = function(e) {
+      cli_status_clear(id = sb)
+      cli_alert_danger(paste0("Error processing JSON response: ", e$message))
+      return(NULL)
+    }
+  )
+
   if (is.null(token_data)) {
     return(NULL)
   }
-  
+
   access_token <- token_data$access_token
 
   cli_status_clear(id = sb)
